package com.emato.file.tunnel.router;

import com.emato.file.tunnel.common.constant.MessageTypeEnum;
import com.emato.file.tunnel.config.properties.RabbitMQProperties;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;

/**
 * <p></p>
 * 路由回执报文到对应的队列
 * @author : lhm
 * @date : 2021-10-01 15:40
 **/
@Component
@Slf4j
public class ReceiptMessageRouter {

    @Autowired
    RabbitMQProperties rabbitMQProperties;

    @Autowired
    @Qualifier("receiptRabbitTemplate")
    RabbitTemplate receiptRabbitTemplate;

    /**
     * 根据回执文件名发送到队列
     * @param messageTypeEnum      回执类型
     * @param message   回执内容
     * @param correlationData correlationData
     * @return          是否路由正确
     */
    public Boolean router (MessageTypeEnum messageTypeEnum, Object message, CorrelationData correlationData) {

        switch (messageTypeEnum) {
            case CEB312:
                receiptRabbitTemplate.convertAndSend(rabbitMQProperties.getK_normal_tunnel_to_csp_receipt_311(), message, correlationData);
                break;
            case CEB622:
                receiptRabbitTemplate.convertAndSend(rabbitMQProperties.getK_normal_tunnel_to_csp_receipt_621(), message, correlationData);
                break;
            case CEB624:
                receiptRabbitTemplate.convertAndSend(rabbitMQProperties.getK_normal_tunnel_to_csp_receipt_623(), message, correlationData);
                break;
            case CEB626:
                receiptRabbitTemplate.convertAndSend(rabbitMQProperties.getK_normal_tunnel_to_csp_receipt_625(), message, correlationData);
                break;
            case CEB816:
                receiptRabbitTemplate.convertAndSend(rabbitMQProperties.getK_normal_tunnel_to_csp_receipt_816(), message, correlationData);
                break;
            case UNKNOWN:
                log.error("----- 未知的消息类型, 消息体: {} -----", message);
            default:
                return false;
        }
        return true;
    }

}
